# #! /usr/bin/env python

# Load Libraries
import numpy as np
import scipy as sp
import matplotlib as mpl
mpl.use('Agg')


import matplotlib.pyplot as plt
import pandas as pd
import seaborn as sns
import pytest
from .. import api


# Fixtures.
@pytest.fixture
def create_dummy_dataset(seed=None, n=30, base_mean=0, expt_groups=6,
                         scale_means=2, scale_std=1.2):
    """
    Creates a dummy dataset for plotting.

    Returns the seed used to generate the random numbers,
    the maximum possible difference between mean differences,
    and the dataset itself.
    """

    # Set a random seed.
    if seed is None:
        random_seed = np.random.randint(low=1, high=1000, size=1)[0]
    else:
        if isinstance(seed, int):
            random_seed = seed
        else:
            raise TypeError('{} is not an integer.'.format(seed))

    # Generate a set of random means
    np.random.seed(random_seed)
    MEANS = np.repeat(base_mean, expt_groups) + np.random.random(size=expt_groups) * scale_means
    SCALES = np.random.random(size=expt_groups) * scale_std

    max_mean_diff = np.ptp(MEANS)

    dataset = list()
    for i, m in enumerate(MEANS):
        pop = sp.stats.norm.rvs(loc=m, scale=SCALES[i], size=10000)
        sample = np.random.choice(pop, size=n, replace=False)
        dataset.append(sample)

    df = pd.DataFrame(dataset).T
    df.columns = [str(c) for c in df.columns]

    return random_seed, max_mean_diff, df



@pytest.fixture
def get_swarm_yspans(coll, round_result=False, decimals=12):
    """
    Given a matplotlib Collection, will obtain the y spans
    for the collection. Will return None if this fails.

    Modified from `get_swarm_spans` in plot_tools.py.
    """
    _, y = np.array(coll.get_offsets()).T
    try:
        if round_result:
            return np.around(y.min(), decimals), np.around(y.max(),decimals)
        else:
            return y.min(), y.max()
    except ValueError:
        return None



# Start tests.
def test_swarmspan():
    print('Testing swarmspans')

    base_mean = np.random.randint(10, 101)
    seed, ptp, df = create_dummy_dataset(base_mean=base_mean)

    print('\nSeed = {}; base mean = {}'.format(seed, base_mean))

    for c in df.columns[1:-1]:
        print('{}...'.format(c))

        f1, swarmplt = plt.subplots(1)
        sns.swarmplot(data=df[[df.columns[0], c]], ax=swarmplt)
        sns_yspans = []
        for coll in swarmplt.collections:
            sns_yspans.append(get_swarm_yspans(coll))

        f2, b = api.plot(data=df, idx=(df.columns[0], c))
        dabest_yspans = []
        for coll in f2.axes[0].collections:
            dabest_yspans.append(get_swarm_yspans(coll))

        for j, span in enumerate(sns_yspans):
            assert span == pytest.approx(dabest_yspans[j])



def test_ylims():
    print('Testing assignment of ylims.')
    seed, ptp, df = create_dummy_dataset(base_mean=0)
    ylim_min = int(np.floor(-ptp) - 1)
    ylim_max = int(np.ceil(ptp) + 1)
    print('seed = {}'.format(seed))


    print('\nTesting assignment of ylims for Cummings plot')
    rand_swarm_ylim1 = (np.random.randint(ylim_min, 0), np.random.randint(ylim_max, ylim_max*2))
    rand_contrast_ylim1 = (np.random.randint(-1, 0), np.random.randint(0, 1))
    print('Swarm ylim = {}, {}'.format(rand_swarm_ylim1[0], rand_swarm_ylim1[1]))
    print('Contrast ylim = {}, {}'.format(rand_contrast_ylim1[0], rand_contrast_ylim1[1]))
    f1, b1 = api.plot(data=df,
                   idx=(('0','1'),('2','3')),
                   float_contrast=False,
                   swarm_ylim=rand_swarm_ylim1,
                   contrast_ylim=rand_contrast_ylim1)

    for i in range(0, int(len(f1.axes)/2)):
        assert f1.axes[i].get_ylim() == pytest.approx(rand_swarm_ylim1)
    for i in range(int(len(f1.axes)/2), len(f1.axes)):
        assert f1.axes[i].get_ylim() == pytest.approx(rand_contrast_ylim1)


    print('\nTesting assignment for Gardner-Altman plot')
    rand_swarm_ylim2 = (np.random.randint(ylim_min, 0), np.random.randint(ylim_max, ylim_max*2))
    print('Swarm ylim = {}, {}'.format(rand_swarm_ylim2[0], rand_swarm_ylim2[1]))
    f2, b2 = api.plot(data=df,
                   idx=(('0','1'),('2','3')),
                   float_contrast=True,
                   swarm_ylim=rand_swarm_ylim2)

    for i in range(0, int(len(f2.axes)/2)):
        assert f2.axes[i].get_ylim() == pytest.approx(rand_swarm_ylim2)


def test_ylabels():
    print('Testing assignment of ylabels')
    seed, ptp, df = create_dummy_dataset()

    print('Testing ylabel assignment for Gardner-Altman plot')
    f1, _ = api.plot(data=df,
                     idx=(('0','1'),('2','3')),
                     float_contrast=True,
                     swarm_label="Hello",
                     contrast_label="World"
                    )
    assert f1.axes[0].get_ylabel() == 'Hello'

    print('Testing ylabel assignment for Cummings plot')
    f2, _ = api.plot(data=df,
                         idx=(('0','1'),('2','3')),
                         float_contrast=False,
                         swarm_label="Hello Again",
                         contrast_label="World\nFolks"
                        )
    assert f2.axes[0].get_ylabel() == "Hello Again"
    assert f2.axes[2].get_ylabel() == "World\nFolks"



def test_paired():
    print('Testing Gardner-Altman paired plotting')
    seed, ptp, df = create_dummy_dataset()
    f, b = api.plot(data=df,
                   idx=('0','1'),
                   paired=True)
    axx = f.axes[0]
    assert df['0'].tolist() == [l.get_ydata()[0] for l in axx.lines]
    assert df['1'].tolist() == [l.get_ydata()[1] for l in axx.lines]



#!/usr/bin/python
# -*-coding: utf-8 -*-
# Author: Joses Ho
# Email : joseshowh@gmail.com

# CONVENIENCE FUNCTIONS THAT DON'T DIRECTLY DEAL WITH PLOTTING OR
# BOOTSTRAP COMPUTATIONS ARE PLACED HERE.

def merge_two_dicts(x, y):
    """
    Given two dicts, merge them into a new dict as a shallow copy.
    Any overlapping keys in `y` will override the values in `x`.

    Taken from https://stackoverflow.com/questions/38987/
    how-to-merge-two-python-dictionaries-in-a-single-expression

    Keywords:
        x, y: dicts

    Returns:
        A dictionary containing a union of all keys in both original dicts.
    """
    z = x.copy()
    z.update(y)
    return z

def unpack_and_add(l, c):
    """Convenience function to allow me to add to an existing list
    without altering that list."""
    t = [a for a in l]
    t.append(c)
    return(t)



# #! /usr/bin/env python
import pytest
import sys
import numpy as np
import scipy as sp

# This filters out an innocuous warning when pandas is imported,
# but the version has not been compiled against the newest numpy.
import warnings
warnings.filterwarnings("ignore", message="numpy.dtype size changed")

import pandas as pd
from .. import bootstrap_tools as bst



@pytest.fixture
def create_dummy_dataset(seed=None, n=30, base_mean=0, expt_groups=6,
                         scale_means=2, scale_std=1.2):
    """
    Creates a dummy dataset for plotting.

    Returns the seed used to generate the random numbers,
    the maximum possible difference between mean differences,
    and the dataset itself.
    """

    # Set a random seed.
    if seed is None:
        random_seed = np.random.randint(low=1, high=1000, size=1)[0]
    else:
        if isinstance(seed, int):
            random_seed = seed
        else:
            raise TypeError('{} is not an integer.'.format(seed))

    # Generate a set of random means
    np.random.seed(random_seed)
    MEANS = np.repeat(base_mean, expt_groups) + np.random.random(size=expt_groups) * scale_means
    SCALES = np.random.random(size=expt_groups) * scale_std

    max_mean_diff = np.ptp(MEANS)

    dataset = list()
    for i, m in enumerate(MEANS):
        pop = sp.stats.norm.rvs(loc=m, scale=SCALES[i], size=10000)
        sample = np.random.choice(pop, size=n, replace=False)
        dataset.append(sample)

    df = pd.DataFrame(dataset).T
    df.columns = [str(c) for c in df.columns]

    return random_seed, max_mean_diff, df


@pytest.fixture
def is_difference(result):
    assert result.is_difference == True


@pytest.fixture
def is_paired(result):
    assert result.is_paired == True


@pytest.fixture
def check_pvalue_1samp(result):
    assert result.pvalue_1samp_ttest != 'NIL'


@pytest.fixture
def check_pvalue_2samp_unpaired(result):
    assert result.pvalue_2samp_ind_ttest != 'NIL'


@pytest.fixture
def check_pvalue_2samp_paired(result):
    assert result.pvalue_2samp_related_ttest != 'NIL'


@pytest.fixture
def check_mann_whitney(result):
    """Nonparametric unpaired"""
    assert result.pvalue_mann_whitney != 'NIL'
    assert result.pvalue_wilcoxon == 'NIL'


@pytest.fixture
def check_wilcoxon(result):
    """Nonparametric Paired"""
    assert result.pvalue_wilcoxon != 'NIL'
    assert result.pvalue_mann_whitney == 'NIL'


@pytest.fixture
def test_mean_within_ci_bca(mean, result):
    assert mean >= result.bca_ci_low
    assert mean <= result.bca_ci_high


@pytest.fixture
def test_mean_within_ci_pct(mean, result):
    assert mean >= result.pct_ci_low
    assert mean <= result.pct_ci_high


@pytest.fixture
def single_samp_stat_tests(sample, result):

    assert result.is_difference == False
    assert result.is_paired == False

    ttest_result = sp.stats.ttest_1samp(sample, 0).pvalue
    assert result.pvalue_1samp_ttest == pytest.approx(ttest_result)


@pytest.fixture
def unpaired_stat_tests(control, expt, result):
    is_difference(result)
    check_pvalue_2samp_unpaired(result)
    check_mann_whitney(result)

    true_mean = expt.mean() - control.mean()
    assert result.summary == pytest.approx(true_mean)

    scipy_ttest_ind_result = sp.stats.ttest_ind(control, expt).pvalue
    assert result.pvalue_2samp_ind_ttest == pytest.approx(scipy_ttest_ind_result)

    mann_whitney_result = sp.stats.mannwhitneyu(control, expt,
                                                alternative='two-sided').pvalue
    assert result.pvalue_mann_whitney == pytest.approx(mann_whitney_result)


@pytest.fixture
def paired_stat_tests(control, expt, result):
    is_difference(result)
    is_paired(result)
    check_wilcoxon(result)

    true_mean = np.mean(expt - control)
    assert result.summary == pytest.approx(true_mean)

    scipy_ttest_paired = sp.stats.ttest_rel(control, expt).pvalue
    assert result.pvalue_2samp_paired_ttest == pytest.approx(scipy_ttest_paired)

    wilcoxon_result = sp.stats.wilcoxon(control, expt).pvalue
    assert result.pvalue_wilcoxon == pytest.approx(wilcoxon_result)


@pytest.fixture
def does_ci_captures_mean_diff(control, expt, paired, nreps=100, alpha=0.05):
    if expt is None:
        mean_diff = control.mean()
    else:
        if paired is True:
            mean_diff = np.mean(expt - control)
        elif paired is False:
            mean_diff = expt.mean() - control.mean()

    ERROR_THRESHOLD = nreps * alpha
    error_count_bca = 0
    error_count_pct = 0

    for i in range(1, nreps):
        results = bst.bootstrap(control, expt, paired=paired, alpha_level=alpha)

        print("\n95CI BCa = {}, {}".format(results.bca_ci_low, results.bca_ci_high))
        try:
            test_mean_within_ci_bca(mean_diff, results)
        except AssertionError:
            error_count_bca += 1

        print("\n95CI %tage = {}, {}".format(results.pct_ci_low, results.pct_ci_high))
        try:
            test_mean_within_ci_pct(mean_diff, results)
        except AssertionError:
            error_count_pct += 1

    print('\nNumber of BCa CIs not capturing the mean is {}'.format(error_count_bca))
    assert error_count_bca < ERROR_THRESHOLD

    print('\nNumber of Pct CIs not capturing the mean is {}'.format(error_count_pct))
    assert error_count_pct < ERROR_THRESHOLD




# Start tests below.
def test_single_sample_bootstrap(mean=100, sd=10, n=25, nreps=100, alpha=0.05):
    print("Testing single sample bootstrap.")

    # Set the random seed.
    random_seed = np.random.randint(low=1, high=1000, size=1)[0]
    np.random.seed(random_seed)
    print("\nRandom seed = {}".format(random_seed))

    # single sample
    pop = sp.stats.norm.rvs(loc=mean, scale=sd * np.random.random(1)[0], size=10000)
    sample = np.random.choice(pop, size=n, replace=False)
    print("\nMean = {}".format(mean))

    results = bst.bootstrap(sample, alpha_level=alpha)
    single_samp_stat_tests(sample, results)

    does_ci_captures_mean_diff(sample, None, False, nreps, alpha)



def test_unpaired_difference(mean=100, sd=10, n=25, nreps=100, alpha=0.05):
    print("Testing unpaired difference bootstrap.\n")

    rand_delta = np.random.randint(-10, 10) # randint between -10 and 10
    SCALES = sd * np.random.random(2)

    pop1 = sp.stats.norm.rvs(loc=mean, scale=SCALES[0], size=10000)
    sample1 = np.random.choice(pop1, size=n, replace=False)

    pop2 = sp.stats.norm.rvs(loc=mean+rand_delta, scale=SCALES[1], size=10000)
    sample2 = np.random.choice(pop2, size=n, replace=False)

    results = bst.bootstrap(sample1, sample2, paired=False, alpha_level=alpha)
    unpaired_stat_tests(sample1, sample2, results)

    does_ci_captures_mean_diff(sample1, sample2, False, nreps, alpha)



def test_paired_difference(mean=100, sd=10, n=25, nreps=100, alpha=0.05):
    print("Testing paired difference bootstrap.\n")

    # Assume equal variances here, given that the samples
    # are supposed to be paired.

    rand_delta = np.random.randint(-10, 10) # randint between -10 and 10
    print('difference={}'.format(rand_delta))
    SCALE = sd * np.random.random(1)[0]

    pop1 = sp.stats.norm.rvs(loc=mean, scale=SCALE, size=10000)
    sample1 = np.random.choice(pop1, size=n, replace=False)

    pop2 = sp.stats.norm.rvs(loc=mean+rand_delta, scale=SCALE, size=10000)
    sample2 = np.random.choice(pop2, size=n, replace=False)

    results = bst.bootstrap(sample1, sample2, alpha_level=alpha, paired=True)
    paired_stat_tests(sample1, sample2, results)

    does_ci_captures_mean_diff(sample1, sample2, True, nreps, alpha)



#!/usr/bin/python
# -*-coding: utf-8 -*-
# Author: Joses Ho
# Email : joseshowh@gmail.com
# A set of convenience functions used for producing plots in `dabest`.



import matplotlib.pyplot as plt
import seaborn as sns
import numpy as np

from .misc_tools import merge_two_dicts



def halfviolin(v, half = 'right', color = 'k'):
    for b in v['bodies']:
            mVertical = np.mean(b.get_paths()[0].vertices[:, 0])
            mHorizontal = np.mean(b.get_paths()[0].vertices[:, 1])
            vertices = b.get_paths()[0].vertices
            if half is 'left':
                b.get_paths()[0].vertices[:, 0] = np.clip(vertices[:, 0],
                                                    -np.inf, mVertical)
            if half is 'right':
                b.get_paths()[0].vertices[:, 0] = np.clip(vertices[:, 0],
                                                    mVertical, np.inf)
            if half is 'bottom':
                b.get_paths()[0].vertices[:, 1] = np.clip(vertices[:, 1],
                                                    -np.inf, mHorizontal)
            if half is 'top':
                b.get_paths()[0].vertices[:, 1] = np.clip(vertices[:, 1],
                                                    mHorizontal, np.inf)
            b.set_color(color)



def align_yaxis(ax1, v1, ax2, v2):
    """adjust ax2 ylimit so that v2 in ax2 is aligned to v1 in ax1"""
    # Taken from
    # http://stackoverflow.com/questions/7630778/
    # matplotlib-align-origin-of-right-axis-with-specific-left-axis-value
    _, y1 = ax1.transData.transform((0, v1))
    _, y2 = ax2.transData.transform((0, v2))
    inv = ax2.transData.inverted()
    _, dy = inv.transform((0, 0)) - inv.transform((0, y1-y2))
    miny, maxy = ax2.get_ylim()
    ax2.set_ylim(miny+dy, maxy+dy)

def rotate_ticks(axes, angle=45, alignment='right'):
    for tick in axes.get_xticklabels():
        tick.set_rotation(angle)
        tick.set_horizontalalignment(alignment)



def get_swarm_spans(coll):
    """
    Given a matplotlib Collection, will obtain the x and y spans
    for the collection. Will return None if this fails.
    """
    import numpy as np
    x, y = np.array(coll.get_offsets()).T
    try:
        return x.min(), x.max(), y.min(), y.max()
    except ValueError:
        return None



def gapped_lines(data, x, y,
                 type='mean_sd',
                 offset=0.3,
                 ax=None,
                 **kwargs):
    '''
    Convenience function to plot the standard devations as vertical
    errorbars. The mean is a gap defined by negative space.

    This style is inspired by Edward Tufte's redesign of the boxplot.
    See The Visual Display of Quantitative Information (1983), pp.128-130.

    Keywords
    --------
    data: pandas DataFrame.
        This DataFrame should be in 'long' format.

    x, y: string.
        x and y columns to be plotted.

    type: ['mean_sd', 'median_quartiles',], default 'mean_sd'
        Plots the summary statistics for each group. If 'mean_sd', then the
        mean and standard deviation of each group is plotted as a gapped line.
        If 'median_quantiles', then the median and 25th and 75th percentiles of
        each group is plotted instead.

    offset: float, default 0.3
        The x-offset of the mean-sd line.

    ax: matplotlib Axes object, default None
        If a matplotlib Axes object is specified, the gapped lines will be
        plotted in order on this axes. If None, the current axes (plt.gca())
        is used.

    kwargs: dict, default None
        Dictionary with kwargs passed to matplotlib.lines.Line2D
    '''
    import matplotlib.lines as mlines

    if ax is None:
        ax = plt.gca()

    keys = kwargs.keys()
    if 'zorder' not in keys:
        kwargs['zorder'] = 5

    if 'lw' not in keys:
        kwargs['lw'] = 4.

    if 'color' not in keys:
        kwargs['color'] = 'black'

    means = data.groupby(x)[y].mean()
    sd = data.groupby(x)[y].std()
    pooled_sd = sd.mean()
    lower_sd = means - sd
    upper_sd = means + sd

    medians = data.groupby(x)[y].median()
    quantiles = data.groupby(x)[y].quantile([0.25, 0.75]).unstack()
    lower_quartiles = quantiles[0.25]
    upper_quartiles = quantiles[0.75]

    if type == 'mean_sd':
        central_measures = means
        lows = lower_sd
        highs = upper_sd
    elif type == 'median_quartiles':
        central_measures = medians
        lows = lower_quartiles
        highs = upper_quartiles

    original_zorder = kwargs['zorder']
    span_color = kwargs['color']
    span_lw = kwargs['lw']
    for xpos, cm in enumerate(central_measures):
        # add vertical span line.
        kwargs['zorder'] = original_zorder
        kwargs['color'] = span_color
        kwargs['lw'] = span_lw
        low_to_high = mlines.Line2D([xpos+offset, xpos+offset],
                                    [lows[xpos], highs[xpos]],
                                      **kwargs)
        ax.add_line(low_to_high)

        # add horzontal central measure line.
        kwargs['zorder'] = 6
        kwargs['color'] = 'white'
        kwargs['lw'] = span_lw + 0.5
        mean_line = mlines.Line2D([xpos+offset-0.01,
                                    xpos+offset+0.01],
                                    [cm, cm],
                                    **kwargs)
        ax.add_line(mean_line)



from setuptools import setup, find_packages
import os
# Taken from setup.py in seaborn.
# temporarily redirect config directory to prevent matplotlib importing
# testing that for writeable directory which results in sandbox error in
# certain easy_install versions
os.environ["MPLCONFIGDIR"]="."

DESCRIPTION = 'Data Analysis and Visualization using Bootstrap-Coupled Estimation.'
LONG_DESCRIPTION = """\
Estimation statistics is a simple framework <https://thenewstatistics.com/itns/>
that—while avoiding the pitfalls of significance testing—uses familiar statistical
concepts: means, mean differences, and error bars. More importantly, it focuses on
the effect size of one's experiment/intervention, as opposed to
significance testing.

An estimation plot has two key features. Firstly, it presents all
datapoints as a swarmplot, which orders each point to display the
underlying distribution. Secondly, an estimation plot presents the
effect size as a bootstrap 95% confidence interval on a separate but
aligned axes.

Please cite this work as:
Moving beyond P values: Everyday data analysis with estimation plots
Joses Ho, Tayfun Tumkaya, Sameer Aryal, Hyungwon Choi, Adam Claridge-Chang
https://doi.org/10.1101/377978
"""


# Modified from from setup.py in seaborn.
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup



def need_to_install(library, desired_major_version, desired_minor_version):
    LIB_INSTALLED_VERSION = library.__version__
    LIB_INSTALLED_VERSION_MAJOR = int(LIB_INSTALLED_VERSION.split('.')[0])
    LIB_INSTALLED_VERSION_MINOR = int(LIB_INSTALLED_VERSION.split('.')[1])

    if LIB_INSTALLED_VERSION_MAJOR < desired_major_version:
        return True

    elif LIB_INSTALLED_VERSION_MINOR < desired_minor_version:
        return True

    else:
        return False



def check_dependencies():
    to_install = []


    NUMPY_LATEST_MAJOR = 1
    NUMPY_LATEST_MINOR = 15
    TO_INSTALL = 'numpy=={}.{}'.format(NUMPY_LATEST_MAJOR,
                                       NUMPY_LATEST_MINOR)
    try:
        import numpy
        if need_to_install(numpy, NUMPY_LATEST_MAJOR, NUMPY_LATEST_MINOR):
            to_install.append(TO_INSTALL)
    except ImportError:
        to_install.append(TO_INSTALL)


    SCIPY_LATEST_MAJOR = 1
    SCIPY_LATEST_MINOR = 1
    TO_INSTALL = 'scipy=={}.{}'.format(SCIPY_LATEST_MAJOR,
                                       SCIPY_LATEST_MINOR)
    try:
        import scipy
        if need_to_install(scipy, SCIPY_LATEST_MAJOR, SCIPY_LATEST_MINOR):
            to_install.append(TO_INSTALL)
    except ImportError:
        to_install.append(TO_INSTALL)

    PANDAS_LATEST_MAJOR = 0
    PANDAS_LATEST_MINOR = 23
    TO_INSTALL = 'pandas=={}.{}'.format(PANDAS_LATEST_MAJOR,
                                        PANDAS_LATEST_MINOR)
    try:
        import pandas
        if need_to_install(pandas, PANDAS_LATEST_MAJOR, PANDAS_LATEST_MINOR):
            to_install.append(TO_INSTALL)
    except ImportError:
        to_install.append(TO_INSTALL)


    MPL_LATEST_MAJOR = 2
    MPL_LATEST_MINOR = 2
    TO_INSTALL = 'matplotlib=={}.{}'.format(MPL_LATEST_MAJOR,
                                            MPL_LATEST_MINOR)
    try:
        import matplotlib as mpl
        if need_to_install(mpl, MPL_LATEST_MAJOR, MPL_LATEST_MINOR):
            to_install.append(TO_INSTALL)
    except ImportError:
        to_install.append(TO_INSTALL)


    SNS_LATEST_MAJOR = 0
    SNS_LATEST_MINOR = 9
    TO_INSTALL = 'seaborn=={}.{}'.format(SNS_LATEST_MAJOR,
                                        SNS_LATEST_MINOR)
    try:
        import seaborn
        if need_to_install(pandas, SNS_LATEST_MAJOR, SNS_LATEST_MINOR):
            to_install.append(TO_INSTALL)
    except ImportError:
        to_install.append(TO_INSTALL)

    return to_install



if __name__ == "__main__":

    installs = check_dependencies()

    setup(
        name='dabest',
        author='Joses W. Ho',
        author_email='joseshowh@gmail.com',
        maintainer='Joses W. Ho',
        maintainer_email='joseshowh@gmail.com',
        version='0.1.4',
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=installs,
        url='https://acclab.github.io/DABEST-python-docs',
        download_url='https://www.github.com/ACCLAB/DABEST-python',
        license='BSD 3-clause Clear License'
    )
